@@ -9,7 +9,8 @@ from load_features_utils.feature_creation_utils import \
     map_quantiles_for_entry,  \
     get_p50_value,  \
     create_polynomial_features, \
-    create_time_features
+    create_time_features, \
+    get_load_quantiles
 
 
 def upload_blob(bucket_name, source_file_name, destination_blob_name):
@@ -174,15 +175,14 @@ class CreateCategoricalEncodedVariables(PTransform):
 
 class _CreateLoadQuantiles(DoFn):
 
-    def __init__(self, load_quantile_df):
+    def __init__(self):
         super(_CreateLoadQuantiles, self).__init__()
-        self.load_quantile_df = load_quantile_df
 
     def process(self, data):
 
         # Put into dataframe
         df = pd.DataFrame(data)
-
+        load_quantile_df = get_load_quantiles()
         weight_quantile = []
         weight_p50 = []
         price_quantile = []
@@ -208,16 +208,16 @@ class _CreateLoadQuantiles(DoFn):
                 equipment = "ALL"
 
             # Find global quantile values
-            global_result = self.load_quantile_df.loc[
-                (self.load_quantile_df['pickup_state'] == "GLOBAL") &
-                (self.load_quantile_df["dropoff_state"] == "GLOBAL") &
-                (self.load_quantile_df["equipment_type"] == equipment)]
+            global_result = load_quantile_df.loc[
+                (load_quantile_df['pickup_state'] == "GLOBAL") &
+                (load_quantile_df["dropoff_state"] == "GLOBAL") &
+                (load_quantile_df["equipment_type"] == equipment)]
 
             # Find state to state quantile values
-            state_to_state_result = self.load_quantile_df.loc[
-                (self.load_quantile_df['pickup_state'] == pickup_state) &
-                (self.load_quantile_df["dropoff_state"] == dropoff_state) &
-                (self.load_quantile_df["equipment_type"] == equipment)]
+            state_to_state_result = load_quantile_df.loc[
+                (load_quantile_df['pickup_state'] == pickup_state) &
+                (load_quantile_df["dropoff_state"] == dropoff_state) &
+                (load_quantile_df["equipment_type"] == equipment)]
 
             # If no State to State use Global
             if state_to_state_result.empty:
@@ -275,12 +275,11 @@ class _CreateLoadQuantiles(DoFn):
 
 class CreateLoadQuantiles(PTransform):
 
-    def __init__(self, load_quantile_df):
+    def __init__(self):
         super(CreateLoadQuantiles, self).__init__()
-        self.load_quantile_df = load_quantile_df
 
     def expand(self, pcoll):
-        return pcoll | ParDo(_CreateLoadQuantiles(self.load_quantile_df))
+        return pcoll | ParDo(_CreateLoadQuantiles())
 
 
 class _CreateCyclicTimeFeatures(DoFn):
